import os
import sys

def main():
    if len(sys.argv) != 2:
        print('This script do the setup for cmd.exe', 'Run:', '> win-basic-tools setup', 'Then refresh your cmd.exe', sep='\n')
        quit(0)
    
    if sys.argv[1] == 'uninstall':
        uninstall()
        quit(0)

    if sys.argv[1] != 'setup':
        print('This script do the setup for cmd.exe', 'Run:', '> win-basic-tools setup', sep='\n')
        quit(0)

    assert sys.platform == 'win32'
    
    sources_path = f'{sys.exec_prefix}/Lib/site-packages/win_basic_tools/sources'
    home_path = os.path.expanduser('~')

    with open(f'{home_path}\\.macros.doskey', 'w') as f:
        print(
            f'ls=python {sources_path}\\ls.py $*',
            f'll=python {sources_path}\\ls.py -lac $*',
            f'which=python {sources_path}\\which.py $1',
            f'touch=python {sources_path}\\touch.py $*',
            'cat=type $1',
            'pwd=cd',
            'mv=move $1 $2',
            'rm=del $*',
            sep='\n',
            file=f)
        
        
    os.system(f'reg add "HKCU\\Software\\Microsoft\\Command Processor" /v Autorun /d "doskey /macrofile=\\"{home_path}\\.macros.doskey\"" /f')

def uninstall():
    home_path = os.path.expanduser('~')

    os.system(f'reg delete "HKCU\\Software\\Microsoft\\Command Processor" /v Autorun')
    os.system(f'del {home_path}\\.macros.doskey')
    print('Refresh you cmd.exe for complete uninstall')

if __name__ == '__main__':
    main()


import sys
import os
import stat
import time
from colorama import Fore, Style, init, deinit


class Ls:
    '''This is a simple Python class for listing the content of a directory.
    The sole purpose is giving portability to the common ls command to Windows systems'''

    just = 7

    def __init__(self, opt='', path='.') -> None:

        if not opt or opt.startswith('-'):
            self.opt, self.path = opt, path
        else:
            self.opt, self.path = '', opt

    def echo(self, signal: int) -> None:
        try:
            with os.scandir(self.path) as dir:
                dir = sorted(dir, key=lambda x: (x.stat().st_mode, x.name))

                if 'l' in self.opt:
                    for i in dir:
                        if i.name.startswith('.') and 'a' not in self.opt:
                            continue
                        
                        # print() by 'column item' for better performance
                        print(self._colorful_permissions(stat.filemode(i.stat().st_mode), 'c' in self.opt), end='   ')
                        print(time.strftime('%d %b %y %H:%M', time.localtime(i.stat().st_ctime)), end='   ')
                        print(self._human_color(self._humanize(i), 'c' in self.opt).rjust(self.just), end='   ')
                        print(self._type_color(i, 'c' in self.opt))

                else:
                    print(*[self._type_color(i, 'c' in self.opt) for i in dir \
                        if not i.name.startswith('.') or 'a' in self.opt], sep='   ') 

        except PermissionError as err:
            if signal: # not going recursively on echo()
                print(f'{str(err)[:12]} {err.strerror}: {err.filename}')
                deinit()
                quit()

            try:
                self.path = os.path.realpath(self.path)
                self.echo(1)
                print(Style.RESET_ALL +
                    f"\nYou can't access files from here because CD doesn't follow symlinks. Do first: cd {os.path.realpath('.')}"
                    )

            except PermissionError:
                pass
        
        except FileNotFoundError as err:
            print(err)

    def _type_color(self, i: os.DirEntry, colors: bool) -> str:
        if not colors:
            return i.name

        #if i.is_symlink(): doesn't work
            
        if i.is_dir():                
            if os.path.realpath(i.path) != os.path.join(os.path.realpath(self.path), i.name): # workaround
                return Fore.CYAN + i.name + Fore.LIGHTBLACK_EX + ' --> ' + os.path.realpath(i.path)

            return Fore.LIGHTBLUE_EX + i.name

        else:
            if i.name.endswith(('.zip', '.exe', '.msi', '.dll', '.bat', '.sys', '.log', '.ini')):
                return Fore.YELLOW + i.name
            if i.name.endswith(('.py', '.pyx', '.pyd', '.pyw')):
                return Fore.GREEN + i.name
            if i.name.endswith(('.tmp')):
                return Fore.LIGHTBLACK_EX + i.name
            if i.name.endswith(('.pdf')):
                return Fore.LIGHTRED_EX + i.name
            return i.name

    def _humanize(self, i: os.DirEntry):
        if i.is_dir():
            return '-'

        entry = i.stat().st_size 
        units = ('k', 'M', 'G')
        final = ''

        for unit in units:
            if entry >= 1024:
                entry /= 1024
                final = unit
            else:
                break

        if entry:
            if final:
                return f'{entry:.1f}{final}'
            return str(entry)
        return '-'

    def _human_color(self, data: str, colors: bool) -> str:
        if not colors:
            return data

        self.just = 16

        if 'G' in data:
            return Fore.RED + data + Style.RESET_ALL
        elif 'M' in data:
            return Fore.LIGHTRED_EX + data + Style.RESET_ALL
        elif 'k' in data:
            return Fore.LIGHTYELLOW_EX + data + Style.RESET_ALL
        else:
            return Fore.WHITE + data + Style.RESET_ALL


    def _colorful_permissions(self, data: os.stat_result.st_mode, colors: bool) -> str:
        if not colors:
            return data

        lis = list(data)
        lis.insert(-3, Fore.LIGHTRED_EX)
        lis.insert(4, Fore.LIGHTYELLOW_EX)
        lis.insert(1, Fore.LIGHTGREEN_EX)
        if lis[0] == 'd': lis.insert(0, Fore.LIGHTBLUE_EX)
        lis.append(Style.RESET_ALL)

        return ''.join(lis)


def main():
    init()

    args = sys.argv[1:]

    #For Powershell and Unix compatibility
    if len(args) > 2:
        print(f'Ignored {sys.argv[3:]} parameter(s)')
        args = args[:2]

    Ls(*args).echo(0)
    deinit()


if __name__ == '__main__':
    main()


import sys

def main():
    if len(sys.argv) < 2:
        print('Pass search filters as parameters', '> ... | grep .exe .dll', sep='\n')
        quit(0)

    try:
        while 1:
            line = input()
            for arg in sys.argv[1:]:
                if arg in line:
                    print(line)
    except EOFError:
        pass

if __name__ == '__main__':
    main()


import shutil
import os
import sys

def main():
    if shutil.which(sys.argv[-1]):
        print(shutil.which(sys.argv[-1]))
        return
    
    with open(os.path.expanduser('~\\.macros.doskey')) as file:
        list_file = file.read().splitlines()
        for i in list_file:
            ind = i.index('=')
            if sys.argv[-1] == i[:ind]:
                print(f'"{sys.argv[-1]}" aliased in "~\\.macros.doskey"')
                return
    
    print('Command not found')

if __name__ == '__main__':
    main()